@@ -91,8 +91,7 @@ enum {
 
 
 static GObjectClass *st_parent_class = NULL;
-static gint          st_timeout_msec = 100;
-static gint          st_timeout_usec = 100000;
+static gint          st_burst_timeout = 100;		/* burst timeout in msec */
 
 static GType         register_type( void );
 static void          class_init( NAPivotClass *klass );
@@ -116,6 +115,7 @@ static gulong        time_val_diff( const GTimeVal *recent, const GTimeVal *old
 
 /* NAGConf runtime preferences management */
 static void          monitor_runtime_preferences( NAPivot *pivot );
+static void          on_io_provider_prefs_changed( GConfClient *client, guint cnxn_id, GConfEntry *entry, NAPivot *pivot );
 static void          on_mandatory_prefs_changed( GConfClient *client, guint cnxn_id, GConfEntry *entry, NAPivot *pivot );
 static void          on_preferences_change( GConfClient *client, guint cnxn_id, GConfEntry *entry, NAPivot *pivot );
 static void          display_order_changed( NAPivot *pivot );
@@ -622,15 +622,14 @@ na_pivot_item_changed_handler( NAIIOProvider *provider, const gchar *id, NAPivot
 
 		if( !pivot->private->event_source_id ){
 			pivot->private->event_source_id =
-				g_timeout_add( st_timeout_msec, ( GSourceFunc ) on_item_changed_timeout, pivot );
+				g_timeout_add( st_burst_timeout, ( GSourceFunc ) on_item_changed_timeout, pivot );
 		}
 	}
 }
 
 /*
  * this timer is set when we receive the first event of a serie
- * we continue to loop until last event is at least one half of a
- * second old
+ * we continue to loop until last event is older that our burst timeout
  *
  * there is no race condition here as we are not multithreaded
  * or .. is there ?
@@ -642,17 +641,21 @@ on_item_changed_timeout( NAPivot *pivot )
 	GTimeVal now;
 	gulong diff;
 	GList *ic;
+	gulong timeout_usec = 1000*st_burst_timeout;
 
 	g_return_val_if_fail( NA_IS_PIVOT( pivot ), FALSE );
 
-	g_debug( "%s: pivot=%p", thisfn, pivot );
-
 	g_get_current_time( &now );
 	diff = time_val_diff( &now, &pivot->private->last_event );
-	if( diff < st_timeout_usec ){
+	if( diff < timeout_usec ){
 		return( TRUE );
 	}
 
+	/* last individual notification is older that the st_burst_timeout
+	 * so triggers the NAIIOProvider interface and destroys this timeout
+	 */
+	g_debug( "%s: triggering NAIPivotConsumer interfaces", thisfn );
+
 	if( pivot->private->automatic_reload ){
 		na_pivot_load_items( pivot );
 	}
@@ -934,30 +937,44 @@ monitor_runtime_preferences( NAPivot *pivot )
 					pivot ));
 	g_free( path );
 
+	path = gconf_concat_dir_and_key( IPREFS_GCONF_BASEDIR, "io-providers" );
+	list = g_list_prepend( list,
+			na_gconf_monitor_new(
+					path,
+					( GConfClientNotifyFunc ) on_io_provider_prefs_changed,
+					pivot ));
+	g_free( path );
+
 	pivot->private->monitors = list;
 }
 
 static void
-on_mandatory_prefs_changed( GConfClient *client, guint cnxn_id, GConfEntry *entry, NAPivot *pivot )
+on_io_provider_prefs_changed( GConfClient *client, guint cnxn_id, GConfEntry *entry, NAPivot *pivot )
 {
-	const gchar *key;
-	gchar *key_entry;
 	GList *ic;
 
 	g_return_if_fail( NA_IS_PIVOT( pivot ));
 
 	if( !pivot->private->dispose_has_run ){
 
-		key = gconf_entry_get_key( entry );
-		key_entry = g_path_get_basename( key );
-
-		if( !strcmp( key_entry, "locked" )){
-			for( ic = pivot->private->consumers ; ic ; ic = ic->next ){
-				na_ipivot_consumer_notify_of_mandatory_prefs_changed( NA_IPIVOT_CONSUMER( ic->data ));
-			}
+		for( ic = pivot->private->consumers ; ic ; ic = ic->next ){
+			na_ipivot_consumer_notify_of_io_provider_prefs_changed( NA_IPIVOT_CONSUMER( ic->data ));
 		}
+	}
+}
 
-		g_free( key_entry );
+static void
+on_mandatory_prefs_changed( GConfClient *client, guint cnxn_id, GConfEntry *entry, NAPivot *pivot )
+{
+	GList *ic;
+
+	g_return_if_fail( NA_IS_PIVOT( pivot ));
+
+	if( !pivot->private->dispose_has_run ){
+
+		for( ic = pivot->private->consumers ; ic ; ic = ic->next ){
+			na_ipivot_consumer_notify_of_mandatory_prefs_changed( NA_IPIVOT_CONSUMER( ic->data ));
+		}
 	}
 }
 
